@@ -283,7 +283,11 @@ def pairing(x1, y1, x2, y2):
     :type y2: list
     :returns: the result
     '''
-    v = _algo5(x1, y1, x2, y2)
+    if (f3m._m - 1)//2 % 2 == 0:
+        f = _algo5
+    else:
+        f = _algo4
+    v = f(x1, y1, x2, y2)
     return _algo8(v)
 
 def init(bits_of_order_of_G1):
